==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.md <==
# AmazonAuroraOracleInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')
```



| Illustration | AmazonAuroraOracleInstanceAlternate | AmazonAuroraOracleInstanceAlternateCard | AmazonAuroraOracleInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.png) | ![illustration for AmazonAuroraOracleInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.Local.png) | ![illustration for AmazonAuroraOracleInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraOracleInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternateGroup.Local.png) |




## AmazonAuroraOracleInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternate('AmazonAuroraOracleInstanceAlternate', 'Amazon Aurora Oracle Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternate('AmazonAuroraOracleInstanceAlternate', 'Amazon Aurora Oracle Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraOracleInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateCard('AmazonAuroraOracleInstanceAlternateCard', 'Amazon Aurora Oracle Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateCard('AmazonAuroraOracleInstanceAlternateCard', 'Amazon Aurora Oracle Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraOracleInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateGroup('AmazonAuroraOracleInstanceAlternateGroup', 'Amazon Aurora Oracle Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateGroup('AmazonAuroraOracleInstanceAlternateGroup', 'Amazon Aurora Oracle Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.md <==
# AmazonAuroraOracleInstanceAlternate


```text
aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate
```

```text
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')
```



| Illustration | AmazonAuroraOracleInstanceAlternate | AmazonAuroraOracleInstanceAlternateCard | AmazonAuroraOracleInstanceAlternateGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.png) | ![illustration for AmazonAuroraOracleInstanceAlternate](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate.Local.png) | ![illustration for AmazonAuroraOracleInstanceAlternateCard](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternateCard.Local.png) | ![illustration for AmazonAuroraOracleInstanceAlternateGroup](../../../aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternateGroup.Local.png) |




## AmazonAuroraOracleInstanceAlternate

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternate('AmazonAuroraOracleInstanceAlternate', 'Amazon Aurora Oracle Instance Alternate', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternate
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternate('AmazonAuroraOracleInstanceAlternate', 'Amazon Aurora Oracle Instance Alternate', 'an optional tech label')
@enduml
```

## AmazonAuroraOracleInstanceAlternateCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateCard('AmazonAuroraOracleInstanceAlternateCard', 'Amazon Aurora Oracle Instance Alternate Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateCard
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateCard('AmazonAuroraOracleInstanceAlternateCard', 'Amazon Aurora Oracle Instance Alternate Card', 'an optional description')
@enduml
```

## AmazonAuroraOracleInstanceAlternateGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateGroup('AmazonAuroraOracleInstanceAlternateGroup', 'Amazon Aurora Oracle Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AmazonAuroraOracleInstanceAlternateGroup
include('aws-q3-2021/Resource/Database/AmazonAuroraOracleInstanceAlternate')

' renders the element
AmazonAuroraOracleInstanceAlternateGroup('AmazonAuroraOracleInstanceAlternateGroup', 'Amazon Aurora Oracle Instance Alternate Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
